Aerospike.Batch.Put (Aerospike Driver v0.3.1)

Copy Markdown View Source

Batch put entry built by Aerospike.Batch.put/2.

Summary

Types

t()

Batch put entry with bins to write for one key.

Types

t()

@type t() :: %Aerospike.Batch.Put{
  bins: Aerospike.Record.bins_input(),
  key: Aerospike.Key.t(),
  opts: Aerospike.batch_record_write_opts()
}

Batch put entry with bins to write for one key.