Aerospike.Page (Aerospike Driver v0.3.1)

Copy Markdown View Source

One page of collected query results with a resumable partition cursor.

Returned by Aerospike.scan_page/3 and Aerospike.query_page/3. The page contains the records collected for this request plus cursor state for the next request when more partitions remain.

Summary

Types

t()

One collected page of records.

Types

t()

@type t() :: %Aerospike.Page{
  cursor: Aerospike.Cursor.t() | nil,
  done?: boolean(),
  records: [Aerospike.Record.t()]
}

One collected page of records.

cursor is nil when no resume state is needed. done? indicates whether the server-side partition walk has completed. A page is not guaranteed to contain exactly the requested maximum number of records.